import React from 'react';
import { Route, Redirect, RouteProps } from 'react-router-dom';
import { NonAuthRoutes } from 'components/api/routes';

/**
 * A wrapper for <Route> that redirects to the login screen if you're not yet authenticated.
 * */

type Props = {
  Component: React.FC<RouteProps>;
  path: string;
};

/* eslint-disable react/jsx-props-no-spreading */
export const PrivateRoute = ({ Component, path }: Props): JSX.Element => {
  const isAuthed = false;
  const message = 'Please log in to view this page';
  return (
    <Route
      exact={false}
      path={path}
      render={(props: RouteProps) =>
        isAuthed ? (
          <Component {...props} />
        ) : (
          <Redirect
            to={{
              pathname: NonAuthRoutes.login,
              state: {
                message,
                requestedPath: path,
              },
            }}
          />
        )
      }
    />
  );
};
